"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateSetupUri = exports.generateSetupHash = exports.generateSetupId = void 0;
var tslib_1 = require("tslib");
var crypto = tslib_1.__importStar(require("crypto"));
function generateSetupId() {
    var chars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
    var max = chars.length;
    var setupID = "";
    for (var i = 0; i < 4; i++) {
        var index = Math.floor(Math.random() * max);
        setupID += chars.charAt(index);
    }
    return setupID;
}
exports.generateSetupId = generateSetupId;
function generateSetupHash(deviceId, setupId) {
    if (!setupId.match(/^[0-9A-Z]{4}$/)) {
        throw new Error("Invalid setup ID");
    }
    return crypto.createHash("sha512")
        .update(setupId + deviceId)
        .digest()
        .slice(0, 4)
        .toString("base64");
}
exports.generateSetupHash = generateSetupHash;
function generateSetupUri(setupCode, setupId, category) {
    if (category === void 0) { category = 1 /* OTHER */; }
    if (typeof setupCode === "string") {
        setupCode = parseInt(setupCode.replace(/-/g, ""), 10);
    }
    var buffer = Buffer.alloc(8);
    var value_low = setupCode;
    var value_high = category >> 1;
    value_low |= 1 << 28; // Supports IP;
    buffer.writeUInt32BE(value_low, 4);
    if (category & 1) {
        buffer[4] = buffer[4] | 1 << 7;
    }
    buffer.writeUInt32BE(value_high, 0);
    var encodedPayload = (buffer.readUInt32BE(4) + (buffer.readUInt32BE(0) * Math.pow(2, 32)))
        .toString(36).toUpperCase();
    if (encodedPayload.length !== 9) {
        for (var i = 0; i <= 9 - encodedPayload.length; i++) {
            encodedPayload = "0" + encodedPayload;
        }
    }
    return "X-HM://" + encodedPayload + setupId;
}
exports.generateSetupUri = generateSetupUri;
//# sourceMappingURL=setupid.js.map